@@ -18,8 +18,9 @@ import functools
 import gzip
 import os
 import re
-from typing import Dict, Iterable, List, Optional, Tuple, Type, TypeVar, Union
 import warnings
+from collections.abc import Iterable, Mapping, Sequence
+from typing import Optional, Type, TypeVar, Union
 
 from google import protobuf
 from google.protobuf import json_format
@@ -127,10 +128,10 @@ def build_compound(
 
 def set_solute_moles(
     solute: reaction_pb2.Compound,
-    solvents: List[reaction_pb2.Compound],
+    solvents: Sequence[reaction_pb2.Compound],
     concentration: str,
     overwrite: bool = False,
-) -> List[reaction_pb2.Compound]:
+) -> list[reaction_pb2.Compound]:
     """Helps define components for stock solution inputs with a single solute
     and a one or more solvent compounds.
 
@@ -179,7 +180,7 @@ def set_solute_moles(
         concentration_pb,
     )
     solute.amount.MergeFrom(solute_moles)
-    return [solute] + solvents
+    return [solute] + list(solvents)
 
 
 def build_data(filename: str, description: str) -> reaction_pb2.Data:
@@ -203,7 +204,7 @@ def build_data(filename: str, description: str) -> reaction_pb2.Data:
     return data
 
 
-def find_submessages(message: ord_schema.Message, submessage_type: Type[MessageType]) -> List[MessageType]:
+def find_submessages(message: ord_schema.Message, submessage_type: Type[MessageType]) -> list[MessageType]:
     """Recursively finds all submessages of a specified type.
 
     Args:
@@ -282,7 +283,7 @@ def molblock_from_compound(compound: reaction_pb2.Compound) -> str:
 # pylint: disable=inconsistent-return-statements
 def mol_from_compound(
     compound: reaction_pb2.Compound, return_identifier: bool = False
-) -> Union[Chem.Mol, Tuple[Chem.Mol, str]]:
+) -> Union[Chem.Mol, tuple[Chem.Mol, str]]:
     """Creates an RDKit Mol from a Compound message.
 
     Args:
@@ -584,7 +585,7 @@ def has_transition_metal(mol: Chem.Mol) -> bool:
     return False
 
 
-def set_dative_bonds(mol: Chem.Mol, from_atoms: Tuple[str, ...] = ("N", "P")) -> Chem.Mol:
+def set_dative_bonds(mol: Chem.Mol, from_atoms: tuple[str, ...] = ("N", "P")) -> Chem.Mol:
     """Converts metal-ligand bonds to dative.
 
     Replaces some single bonds between metals and atoms with atomic numbers
@@ -596,7 +597,7 @@ def set_dative_bonds(mol: Chem.Mol, from_atoms: Tuple[str, ...] = ("N", "P")) ->
 
     Args:
         mol: The molecule to be converted.
-        fromAtoms: tuple of atomic symbols corresponding to atom types that
+        from_atoms: tuple of atomic symbols corresponding to atom types that
         should have atom-metal bonds converted to dative. Default is N and P
 
     Returns:
@@ -840,7 +841,7 @@ def messages_to_dataframe(messages: Iterable[ord_schema.Message], drop_constant_
     return df
 
 
-def message_to_row(message: ord_schema.Message, trace: Optional[Tuple[str]] = None) -> Dict[str, ord_schema.ScalarType]:
+def message_to_row(message: ord_schema.Message, trace: Optional[tuple[str]] = None) -> dict[str, ord_schema.ScalarType]:
     """Converts a proto into a flat dictionary mapping fields to values.
 
     The keys indicate any nesting; for instance a proto that looks like this:
@@ -884,7 +885,7 @@ def message_to_row(message: ord_schema.Message, trace: Optional[Tuple[str]] = No
     return row
 
 
-def safe_update(target: Dict, update: Dict):
+def safe_update(target: dict, update: Mapping) -> None:
     """Checks that `update` will not clobber any keys in `target`."""
     for key in update:
         if key in target:
@@ -895,8 +896,8 @@ def safe_update(target: Dict, update: Dict):
 def _message_to_row(
     field: ord_schema.FieldDescriptor,
     value: Union[ord_schema.Message, ord_schema.ScalarType],
-    trace: Tuple[str],
-) -> Dict[str, ord_schema.ScalarType]:
+    trace: tuple[str],
+) -> dict[str, ord_schema.ScalarType]:
     """Recursively creates a dict for a single value.
 
     Args:
@@ -929,7 +930,7 @@ def parse_doi(doi: str) -> str:
         ValueError: if the DOI cannot be parsed.
     """
     # See https://www.doi.org/doi_handbook/2_Numbering.html#2.2.
-    match = re.search(r"(10\.[\d.]+\/[a-zA-Z\d.]+)", doi)
+    match = re.search(r"(10\.[\d.]+/[a-zA-Z\d.]+)", doi)
     if not match:
         raise ValueError(f"could not parse DOI: {doi}")
     return match.group(1)
